Package: GCPBayes
Type: Package
Title: Bayesian Meta-Analysis of Pleiotropic Effects Using Group
        Structure
Version: 4.3.0
Authors@R: c(
    person("Yazdan", "Asgari", email = "yazdan.asgari@inserm.fr", role = c("aut", "cre")),
	person("Taban", "Baghfalaki", role = "aut"),
	person("Benoit", "Liquet", role = "aut"),
	person("Pierre-Emmanuel", "Sugier", role = "aut"),
	person("Mohammed", "Sedki", role = "aut"),
	person("Therese", "Truong", role = "aut")
	)
Description: Run a Gibbs sampler for a multivariate Bayesian sparse group selection model with Dirac, continuous and hierarchical spike prior for detecting pleiotropy on the traits. This package is designed for summary statistics containing estimated regression coefficients and its estimated covariance matrix. The methodology is available from: Baghfalaki, T., Sugier, P. E., Truong, T., Pettitt, A. N., Mengersen, K., & Liquet, B. (2021) <doi:10.1002/sim.8855>.
URL: https://github.com/tbaghfalaki/GCPBayes
License: GPL (>= 2.0)
Encoding: UTF-8
Imports: MASS, mvtnorm, invgamma, gdata, truncnorm, abind, posterior,
        Rcpp (>= 1.0.9)
LinkingTo: Rcpp, RcppArmadillo
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 3.5.0)
NeedsCompilation: yes
Packaged: 2025-11-28 16:21:12 UTC; asgari
Repository: CRAN
Date/Publication: 2025-11-28 19:20:14 UTC
Author: Yazdan Asgari [aut, cre],
  Taban Baghfalaki [aut],
  Benoit Liquet [aut],
  Pierre-Emmanuel Sugier [aut],
  Mohammed Sedki [aut],
  Therese Truong [aut]
Maintainer: Yazdan Asgari <yazdan.asgari@inserm.fr>
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 07:35:22 UTC; unix
Archs: GCPBayes.so.dSYM
