# Generated by roxygen2: do not edit by hand

export(CS)
export(DS)
export(HS)
export(MCMCplot)
export(summaryCS)
export(summaryDS)
export(summaryHS)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(stats,acf)
importFrom(stats,density)
importFrom(stats,median)
importFrom(stats,pnorm)
importFrom(stats,quantile)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,sd)
useDynLib(GCPBayes, .registration = TRUE)
